==> nextcloud-26.0.11p1.tgz: nextcloud/apps/federatedfilesharing/l10n/eo.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ĉu vi volas aldoni la foran kunhavon {name} de {owner}@{remote}?",
    "Remote share" : "Foran kunhavo",
    "Remote share password" : "Pasvorto de fora kunhavo",
    "Cancel" : "Nuligi",
    "Add remote share" : "Aldoni foran kunhavon",
    "Invalid Federated Cloud ID" : "Nevalida federnuba identigilo",
    "Server to server sharing is not enabled on this server" : "Interservila kunhavo ne estas ebligita en ĉi tiu servilo",
    "Couldn't establish a federated share." : "Ne povis fari federan kunhavon.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Ne povis fari federan kunhavon, eble la pasvorto ne ĝustas.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federkunhava peto sendita, vi ricevos inviton. Kontrolu viajn sciigojn.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Ne povis fari federan kunhavon, ŝajnas, ke la servilo federota estas tro malnova (Nextcloud ⩽ 9).",
    "It is not allowed to send federated group shares from this server." : "Ne estas permesita sendi federajn grupajn kuhavojn el tiu ĉi servilo. ",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar la ero jam kunhaviĝis kun uzanto %2$s",
    "Not allowed to create a federated share with the same user" : "Vi ne rajtas krei federan kunhavon kun la sama uzanto",
    "File is already shared with %s" : "Dosiero jam kuhaviĝas kun %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Kunhavigo de  %1$s malsukcesis, ne eblis trovi %2$s; eble la servilo estas provizore neatingebla aŭ uzas memsubskribitan atestilon.",
    "Could not find share" : "Ne eblis trovi kunhavon",
    "Federated sharing" : "Federa kunhavado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vi ricevis „{share}“ kiel foran kunhavon el {user} (nome de {behalf})",
    "You received {share} as a remote share from {user}" : "Vi ricevis „{share}“ kiel foran kunhavon el {user}",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Federated Cloud Sharing" : "Federnuba kunhavigo",
    "Sharing" : "Kunhavigo",
    "Federated file sharing" : "Federa dosierkunhavado",
    "Provide federated file sharing across servers" : "Provizas federan dosierkunhavigon inter serviloj",
    "Allow users on this server to receive shares from other servers" : "Permesi al uzantoj en tiu ĉi servilo ricevi kunhavojn el aliaj serviloj",
    "Allow users on this server to send shares to groups on other servers" : "Permesi al uzantoj en tiu ĉi servilo sendi kunhavojn al grupoj de aliaj serviloj",
    "Allow users on this server to receive group shares from other servers" : "Permesi al uzantoj en tiu ĉi servilo ricevi kunhavojn el grupoj de aliaj serviloj",
    "Search global and public address book for users" : "Serĉi mallokan kaj publikan adresaron por trovi uzantojn",
    "Allow users to publish their data to a global and public address book" : "Permesi al uzantoj aperigi iliajn datumojn en mallokan kaj publikan adresaron ",
    "Federated Cloud" : "Federa nubo",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vi povas kunhavigi kun iu, kiu uzas Nextcloud aŭ aliaj serviloj kaj servoj kungruaj kun „Open Cloud Mesh (OCM)“! Entajpu simple lian aŭ ŝian federnuban identigilon en la kunhaviga dialogo. Federnuba identigilo similas al persono@nubo.example.com",
    "Your Federated Cloud ID:" : "Via federnuba identigilo:",
    "Share it so your friends can share files with you:" : "Kunhavigu ĝin, por ke viaj amikoj povu kunhavigi dosierojn kun vi:",
    "Twitter" : "Twitter",
    "Add to your website" : "Aldoni al via TTT-ejo",
    "Share with me via Nextcloud" : "Kunhavigi kun mi per Nextcloud",
    "HTML Code:" : "HTML-kodo:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Kunhavigi kun mi per mia #Nextcloud-federnuba identigilo",
    "Copy to clipboard" : "Kopii tondejen",
    "Copied!" : "Kopiita!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.1p0.tgz: nextcloud/apps/federatedfilesharing/l10n/eo.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ĉu vi volas aldoni la foran kunhavon {name} de {owner}@{remote}?",
    "Remote share" : "Foran kunhavo",
    "Remote share password" : "Pasvorto de fora kunhavo",
    "Cancel" : "Nuligi",
    "Add remote share" : "Aldoni foran kunhavon",
    "Invalid Federated Cloud ID" : "Nevalida federnuba identigilo",
    "Server to server sharing is not enabled on this server" : "Interservila kunhavo ne estas ebligita en ĉi tiu servilo",
    "Couldn't establish a federated share." : "Ne povis fari federan kunhavon.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Ne povis fari federan kunhavon, eble la pasvorto ne ĝustas.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federkunhava peto sendita, vi ricevos inviton. Kontrolu viajn sciigojn.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Ne povis fari federan kunhavon, ŝajnas, ke la servilo federota estas tro malnova (Nextcloud ⩽ 9).",
    "It is not allowed to send federated group shares from this server." : "Ne estas permesita sendi federajn grupajn kuhavojn el tiu ĉi servilo. ",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Kunhavigo de %1$s malsukcesis, ĉar la ero jam kunhaviĝis kun uzanto %2$s",
    "Not allowed to create a federated share with the same user" : "Vi ne rajtas krei federan kunhavon kun la sama uzanto",
    "File is already shared with %s" : "Dosiero jam kuhaviĝas kun %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Kunhavigo de  %1$s malsukcesis, ne eblis trovi %2$s; eble la servilo estas provizore neatingebla aŭ uzas memsubskribitan atestilon.",
    "Could not find share" : "Ne eblis trovi kunhavon",
    "Federated sharing" : "Federa kunhavado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vi ricevis „{share}“ kiel foran kunhavon el {user} (nome de {behalf})",
    "You received {share} as a remote share from {user}" : "Vi ricevis „{share}“ kiel foran kunhavon el {user}",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Federated Cloud Sharing" : "Federnuba kunhavigo",
    "Sharing" : "Kunhavigo",
    "Federated file sharing" : "Federa dosierkunhavado",
    "Provide federated file sharing across servers" : "Provizas federan dosierkunhavigon inter serviloj",
    "Allow users on this server to receive shares from other servers" : "Permesi al uzantoj en tiu ĉi servilo ricevi kunhavojn el aliaj serviloj",
    "Allow users on this server to send shares to groups on other servers" : "Permesi al uzantoj en tiu ĉi servilo sendi kunhavojn al grupoj de aliaj serviloj",
    "Allow users on this server to receive group shares from other servers" : "Permesi al uzantoj en tiu ĉi servilo ricevi kunhavojn el grupoj de aliaj serviloj",
    "Search global and public address book for users" : "Serĉi mallokan kaj publikan adresaron por trovi uzantojn",
    "Allow users to publish their data to a global and public address book" : "Permesi al uzantoj aperigi iliajn datumojn en mallokan kaj publikan adresaron ",
    "Federated Cloud" : "Federa nubo",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vi povas kunhavigi kun iu, kiu uzas Nextcloud aŭ aliaj serviloj kaj servoj kungruaj kun „Open Cloud Mesh (OCM)“! Entajpu simple lian aŭ ŝian federnuban identigilon en la kunhaviga dialogo. Federnuba identigilo similas al persono@nubo.example.com",
    "Your Federated Cloud ID:" : "Via federnuba identigilo:",
    "Share it so your friends can share files with you:" : "Kunhavigu ĝin, por ke viaj amikoj povu kunhavigi dosierojn kun vi:",
    "Twitter" : "Twitter",
    "Add to your website" : "Aldoni al via TTT-ejo",
    "Share with me via Nextcloud" : "Kunhavigi kun mi per Nextcloud",
    "HTML Code:" : "HTML-kodo:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Kunhavigi kun mi per mia #Nextcloud-federnuba identigilo",
    "Copy to clipboard" : "Kopii tondejen",
    "Copied!" : "Kopiita!",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Vi ricevis „%3$s“ kiel foran kunhavon el %4$s [%1$s]  (nome de %5$s [%2$s])",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Vi ricevis „%3$s“ kiel foran kunhavon el %4$s (%1$s)",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Kunhavigi kun mi per mia identigilo de #Nextcloud-federnuba identigilo; vidu %s"
},
"nplurals=2; plural=(n != 1);");
